==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicRootPaneUI.h <==
// public class javax.swing.plaf.basic.BasicRootPaneUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 20842320399f1429 javax_swing_plaf_RootPaneUI
// @dep_class c69478c6a89b1c19 javax_swing_plaf_basic_BasicRootPaneUI

// header file dependencies
// @dep_header javax_swing_plaf_RootPaneUI

#include "javax/swing/plaf/RootPaneUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicRootPaneUI_H_
#define _JC_javax_swing_plaf_basic_BasicRootPaneUI_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_refs	_jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$refs	_jc_javax_swing_plaf_basic_BasicRootPaneUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$nonrefs	_jc_javax_swing_plaf_basic_BasicRootPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object	_jc_javax_swing_plaf_basic_BasicRootPaneUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vmethods	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vtable	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vtype	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicRootPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicRootPaneUI$method$installUI$ddb69f0251b0939f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object *, struct _jc_javax_swing_JComponent$object *);
extern void _jc_javax_swing_plaf_basic_BasicRootPaneUI$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicRootPaneUI$method_info$installUI$ddb69f0251b0939f;
extern _jc_method _jc_javax_swing_plaf_basic_BasicRootPaneUI$method_info$propertyChange$6d3500eaa79bf44b;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicRootPaneUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vmethods {
	void	(*installUI$ddb69f0251b0939f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object *, struct _jc_javax_swing_JComponent$object *);
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_RootPaneUI$vmethods	javax_swing_plaf_RootPaneUI;
	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vmethods	javax_swing_plaf_basic_BasicRootPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$refs {
    _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_refs	javax_swing_plaf_basic_BasicRootPaneUI;
    _jc_javax_swing_plaf_RootPaneUI$sub_refs	javax_swing_plaf_RootPaneUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_RootPaneUI$sub_nonrefs	javax_swing_plaf_RootPaneUI;
    _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_nonrefs	javax_swing_plaf_basic_BasicRootPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object {
	_jc_javax_swing_plaf_basic_BasicRootPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicRootPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicRootPaneUI$vtype _jc_javax_swing_plaf_basic_BasicRootPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicRootPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicRootPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicRootPaneUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicRootPaneUI.h <==
// public class javax.swing.plaf.basic.BasicRootPaneUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 20842320399f1429 javax_swing_plaf_RootPaneUI
// @dep_class c69478c6a89b1c19 javax_swing_plaf_basic_BasicRootPaneUI

// header file dependencies
// @dep_header javax_swing_plaf_RootPaneUI

#include "javax/swing/plaf/RootPaneUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicRootPaneUI_H_
#define _JC_javax_swing_plaf_basic_BasicRootPaneUI_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_refs	_jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$refs	_jc_javax_swing_plaf_basic_BasicRootPaneUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$nonrefs	_jc_javax_swing_plaf_basic_BasicRootPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object	_jc_javax_swing_plaf_basic_BasicRootPaneUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vmethods	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vtable	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vtype	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicRootPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicRootPaneUI$method$installUI$ddb69f0251b0939f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicRootPaneUI$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicRootPaneUI$method_info$installUI$ddb69f0251b0939f;
extern _jc_method _jc_javax_swing_plaf_basic_BasicRootPaneUI$method_info$propertyChange$6d3500eaa79bf44b;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicRootPaneUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vmethods {
	void	(*installUI$ddb69f0251b0939f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_RootPaneUI$vmethods	javax_swing_plaf_RootPaneUI;
	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vmethods	javax_swing_plaf_basic_BasicRootPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$refs {
    _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_refs	javax_swing_plaf_basic_BasicRootPaneUI;
    _jc_javax_swing_plaf_RootPaneUI$sub_refs	javax_swing_plaf_RootPaneUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_RootPaneUI$sub_nonrefs	javax_swing_plaf_RootPaneUI;
    _jc_javax_swing_plaf_basic_BasicRootPaneUI$sub_nonrefs	javax_swing_plaf_basic_BasicRootPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicRootPaneUI$object {
	_jc_javax_swing_plaf_basic_BasicRootPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicRootPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicRootPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicRootPaneUI$vtype _jc_javax_swing_plaf_basic_BasicRootPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicRootPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicRootPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicRootPaneUI_H_ */
